import { Callback, Context } from 'aws-lambda';
import { APIGatewayHelper, BaseHelper, CloudWatchHelper, DynamoDBHelper, KMSHelper, LambdaHelper, S3Helper, SESHelper, SNSHelper, SQSHelper, SSMHelper } from './helpers';
import { ILogger, LogLevel } from './logger';
/**
 * IHandler
 */
export interface IHandler {
    APIGatewayHelper: APIGatewayHelper;
    BaseHelper: BaseHelper;
    CloudWatchHelper: CloudWatchHelper;
    DynamoDBHelper: DynamoDBHelper;
    KMSHelper: KMSHelper;
    LambdaHelper: LambdaHelper;
    Logger: ILogger;
    S3Helper: S3Helper;
    SESHelper: SESHelper;
    SNSHelper: SNSHelper;
    SQSHelper: SQSHelper;
    SSMHelpler: SSMHelper;
    Execute<T>(payload: T, context: Context, callback: Callback, actionToExecute: () => Promise<T>): Promise<void>;
}
/**
 * Handles an incoming lambda execution request
 */
export declare class Handler implements IHandler {
    private LogLevel;
    APIGatewayHelper: APIGatewayHelper;
    BaseHelper: BaseHelper;
    CloudWatchHelper: CloudWatchHelper;
    DynamoDBHelper: DynamoDBHelper;
    KMSHelper: KMSHelper;
    LambdaHelper: LambdaHelper;
    Logger: ILogger;
    S3Helper: S3Helper;
    SESHelper: SESHelper;
    SNSHelper: SNSHelper;
    SQSHelper: SQSHelper;
    SSMHelpler: SSMHelper;
    /**
     * Initialize a new instance of Handler
     * @param LogLevel {LogLevel} Log Level
     */
    constructor(LogLevel: LogLevel);
    /**
     * Execute a lambda
     * @param payload {T} Payload to use
     * @param context {Context} AWS Context
     * @param callback {Callback} AWS Callback
     * @param actionToExecute {function} Action to take
     */
    Execute<T>(payload: T, context: Context, callback: Callback<any>, actionToExecute: () => Promise<T>): Promise<void>;
}
