"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const helpers_1 = require("./helpers");
const logger_1 = require("./logger");
/**
 * Handles an incoming lambda execution request
 */
class Handler {
    /**
     * Initialize a new instance of Handler
     * @param LogLevel {LogLevel} Log Level
     */
    // tslint:disable-next-line: no-shadowed-variable
    constructor(LogLevel) {
        this.LogLevel = LogLevel;
        // initialize the Logger
        this.Logger = new logger_1.Logger(this.LogLevel);
        // initialize all the helpers
        this.APIGatewayHelper = new helpers_1.APIGatewayHelper(this.Logger);
        this.BaseHelper = new helpers_1.BaseHelper(this.Logger);
        this.CloudWatchHelper = new helpers_1.CloudWatchHelper(this.Logger);
        this.DynamoDBHelper = new helpers_1.DynamoDBHelper(this.Logger);
        this.KMSHelper = new helpers_1.KMSHelper(this.Logger);
        this.LambdaHelper = new helpers_1.LambdaHelper(this.Logger);
        this.S3Helper = new helpers_1.S3Helper(this.Logger);
        this.SESHelper = new helpers_1.SESHelper(this.Logger);
        this.SNSHelper = new helpers_1.SNSHelper(this.Logger);
        this.SQSHelper = new helpers_1.SQSHelper(this.Logger);
        this.SSMHelpler = new helpers_1.SSMHelper(this.Logger);
    }
    /**
     * Execute a lambda
     * @param payload {T} Payload to use
     * @param context {Context} AWS Context
     * @param callback {Callback} AWS Callback
     * @param actionToExecute {function} Action to take
     */
    Execute(payload, context, callback, actionToExecute) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${Handler.name}.${this.Execute.name}`;
            this.BaseHelper.TraceInputs(action, { payload, context, callback });
            if (this.BaseHelper.IsNullOrEmpty(context)) {
                throw new Error(`[${action}]-Must supply context`);
            }
            let result;
            let error;
            try {
                result = yield actionToExecute();
                this.Logger.Trace(`[${action}]-${JSON.stringify(result)}`);
            }
            catch (err) {
                error = err;
                this.Logger.Error(`[${action}]-${JSON.stringify(error)}`);
            }
            finally {
                callback(error, result);
            }
        });
    }
}
exports.Handler = Handler;
//# sourceMappingURL=handler.js.map