import { ILogger } from '../logger';
export declare class BaseHelper {
    /**
     * Logger
     */
    Logger: ILogger;
    /**
     * Initialize new instance of BaseHelper
     * @param logger {ILogger} Logger
     */
    constructor(logger: ILogger);
    /**
     * Determines whether or not the given value is null or empty
     * @param value {object | string | undefined | null} Value to check if null or empty
     */
    IsNullOrEmpty(value: object | string | undefined | null): boolean;
    /**
     * Determines whether or not the given value is null or whitespace
     * @param value {string | undefined | null} Value to check if null or whitespace
     */
    IsNullOrWhitespace(value: string | undefined | null): boolean;
    /**
     * Converts variables to strings
     * @param value {any} Value to convert to string
     */
    ToString(value: any): string;
    /**
     * Logs the inputs to a function
     * @param action {string} Action method currently in
     * @param inputs {object} Inputs to log
     */
    TraceInputs(action: string, inputs: object): void;
    /**
     * Logs the request to an AWS function call
     * @param action {string} Action method currently in
     * @param inputs {object} Inputs to log
     */
    TraceRequest(action: string, request: object): void;
    /**
     * Logs the response to an AWS function call
     * @param action {string} Action method currently in
     * @param inputs {object} Inputs to log
     */
    TraceResponse(action: string, response: object): void;
}
