"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class BaseHelper {
    /**
     * Initialize new instance of BaseHelper
     * @param logger {ILogger} Logger
     */
    constructor(logger) {
        this.Logger = logger;
    }
    /**
     * Determines whether or not the given value is null or empty
     * @param value {object | string | undefined | null} Value to check if null or empty
     */
    IsNullOrEmpty(value) {
        switch (typeof (value)) {
            case 'object':
                const o = (value || {});
                return Object.keys(o).length === 0;
            case 'string':
                const s = (value || '');
                return s.length < 1;
            default:
                return true;
        }
    }
    /**
     * Determines whether or not the given value is null or whitespace
     * @param value {string | undefined | null} Value to check if null or whitespace
     */
    IsNullOrWhitespace(value) {
        return this.IsNullOrEmpty((value || '').trim());
    }
    /**
     * Converts variables to strings
     * @param value {any} Value to convert to string
     */
    ToString(value) {
        switch (typeof (value)) {
            case 'boolean':
            case 'number':
            case 'string':
                return value.toString();
            case 'object':
                return JSON.stringify(value);
            default:
                return value || '';
        }
    }
    /**
     * Logs the inputs to a function
     * @param action {string} Action method currently in
     * @param inputs {object} Inputs to log
     */
    TraceInputs(action, inputs) {
        this.Logger.Trace(`[${action}]-Inputs: ${JSON.stringify({ inputs })}`);
    }
    /**
     * Logs the request to an AWS function call
     * @param action {string} Action method currently in
     * @param inputs {object} Inputs to log
     */
    TraceRequest(action, request) {
        this.Logger.Trace(`[${action}]-Request: ${JSON.stringify({ request })}`);
    }
    /**
     * Logs the response to an AWS function call
     * @param action {string} Action method currently in
     * @param inputs {object} Inputs to log
     */
    TraceResponse(action, response) {
        this.Logger.Trace(`[${action}]-Response: ${JSON.stringify({ response })}`);
    }
}
exports.BaseHelper = BaseHelper;
//# sourceMappingURL=base.js.map