"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const AWS = require("aws-sdk");
const base_1 = require("./base");
/**
 * CloudWatch Helper
 */
class CloudWatchHelper extends base_1.BaseHelper {
    /**
     * Initializes new instance of CloudWatchHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.CloudWatch} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.CloudWatch.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger, repository, options) {
        super(logger);
        this.Repository = repository || new AWS.CloudWatch(options);
    }
    /**
     * Put data to a metric
     * @param namespace {string} Custom namespace to put data to
     * @param metricData {AWS.CloudWatch.MetricDatum[]} Metric data to put
     */
    PutMetricDataAsync(namespace, metricData) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${CloudWatchHelper.name}.${this.PutMetricDataAsync.name}`;
            this.TraceInputs(action, { namespace, metricData });
            // guard clauses
            if (this.IsNullOrEmpty(namespace)) {
                throw new Error(`[${action}]-Must supply namespace`);
            }
            if (!metricData || metricData.length === 0) {
                throw new Error(`[${action}]-Must supply metricData`);
            }
            // create params object
            const params = {
                MetricData: metricData,
                Namespace: namespace,
            };
            this.TraceRequest(action, params);
            // make AWS call
            const response = yield this.Repository.putMetricData(params).promise();
            this.TraceResponse(action, response);
            return response;
        });
    }
}
exports.CloudWatchHelper = CloudWatchHelper;
//# sourceMappingURL=cloudwatch.js.map