import * as AWS from 'aws-sdk';
import { ILogger } from '../logger';
import { BaseHelper } from './base';
/**
 * SNS Helper
 */
export declare class SNSHelper extends BaseHelper {
    /**
     * AWS Repository for SNS
     */
    private Repository;
    /**
     * Initializes new instance of SNSHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.SNS} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.SNS.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger: ILogger, repository?: AWS.SNS, options?: AWS.SNS.ClientConfiguration);
    /**
     * Publish a message
     * @param topicArn {string} Topic ARN to publish to
     * @param subject {string} Subject of message to send
     * @param message {string} Contents of message to send
     * @param messageAttributes {AWS.SNS.MessageAttributeMap} Attributes to give the message to send
     */
    PublishAsync(topicArn: string, subject: string, message: string, messageAttributes?: AWS.SNS.MessageAttributeMap): Promise<AWS.SNS.PublishResponse>;
}
