export declare enum LogLevel {
    Off = 0,
    Information = 1,
    Warning = 2,
    Error = 3,
    Debug = 4,
    Trace = 5
}
export interface ILogger {
    LogLevel: LogLevel;
    Debug(log?: any): void;
    Error(log?: any): void;
    Information(log?: any): void;
    Trace(log?: any): void;
    Warning(log?: any): void;
    Log(level: LogLevel, log?: any): void;
}
/**
 * Logging class
 */
export declare class Logger implements ILogger {
    /**
     * Logging level
     */
    LogLevel: LogLevel;
    /**
     * Initialize new instance of Logger
     * @param logLevel {LogLevel} Logging level
     */
    constructor(logLevel?: LogLevel);
    /**
     * Logs with Debug LogLevel
     * @param log {any} Message to log
     */
    Debug(log?: any): void;
    /**
     * Logs with Error LogLevel
     * @param log {any} Message to log
     */
    Error(log?: any): void;
    /**
     * Logs with Information LogLevel
     * @param log {any} Message to log
     */
    Information(log?: any): void;
    /**
     * Logs with Trace LogLevel
     * @param log {any} Message to log
     */
    Trace(log?: any): void;
    /**
     * Logs with Warning LogLevel
     * @param log {any} Message to log
     */
    Warning(log?: any): void;
    /**
     * Logs with given LogLevel
     * @param level {LogLevel} Logging level to log at
     * @param log {any} Message to log
     */
    Log(level: LogLevel, log?: any): void;
}
