"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["Off"] = 0] = "Off";
    LogLevel[LogLevel["Information"] = 1] = "Information";
    LogLevel[LogLevel["Warning"] = 2] = "Warning";
    LogLevel[LogLevel["Error"] = 3] = "Error";
    LogLevel[LogLevel["Debug"] = 4] = "Debug";
    LogLevel[LogLevel["Trace"] = 5] = "Trace";
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
/**
 * Logging class
 */
class Logger {
    /**
     * Initialize new instance of Logger
     * @param logLevel {LogLevel} Logging level
     */
    constructor(logLevel = LogLevel.Information) {
        this.LogLevel = logLevel;
    }
    /**
     * Logs with Debug LogLevel
     * @param log {any} Message to log
     */
    Debug(log) {
        this.Log(LogLevel.Debug, log);
    }
    /**
     * Logs with Error LogLevel
     * @param log {any} Message to log
     */
    Error(log) {
        this.Log(LogLevel.Error, log);
    }
    /**
     * Logs with Information LogLevel
     * @param log {any} Message to log
     */
    Information(log) {
        this.Log(LogLevel.Information, log);
    }
    /**
     * Logs with Trace LogLevel
     * @param log {any} Message to log
     */
    Trace(log) {
        this.Log(LogLevel.Trace, log);
    }
    /**
     * Logs with Warning LogLevel
     * @param log {any} Message to log
     */
    Warning(log) {
        this.Log(LogLevel.Warning, log);
    }
    /**
     * Logs with given LogLevel
     * @param level {LogLevel} Logging level to log at
     * @param log {any} Message to log
     */
    Log(level, log) {
        if (this.LogLevel > LogLevel.Off && this.LogLevel >= level) {
            // create the message to log
            const message = `[${LogLevel[level].toUpperCase()}]-${log}`;
            switch (level) {
                case LogLevel.Error:
                    console.error(message);
                    break;
                case LogLevel.Warning:
                    console.warn(message);
                    break;
                default:
                    console.log(message);
                    break;
            }
        }
    }
}
exports.Logger = Logger;
//# sourceMappingURL=logger.js.map