"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_mock_1 = require("./base-mock");
// tslint:disable-next-line: no-var-requires
const AWS = require('aws-sdk');
/**
 * DynamoDB Mock class
 */
class DynamoDBMock extends base_mock_1.BaseMock {
    constructor() {
        super(...arguments);
        /**
         * Mocks an AWS.DynamoDB.DocumentClient.DeleteItemOutput response
         */
        this.DeleteItemOutput = {};
        /**
         * Mocks an AWS.DynamoDB.DocumentClient.GetItemOutput response
         */
        this.GetItemOutput = {};
        /**
         * Mocks an AWS.DynamoDB.DocumentClient.PutItemOutput response
         */
        this.PutItemOutput = {};
        /**
         * Mocks an AWS.DynamoDB.DocumentClient.ScanOutput response
         */
        this.ScanOutput = {};
        /**
         * Mocks an AWS.DynamoDB.DocumentClient.UpdateItemOutput response
         */
        this.UpdateItemOutput = {};
    }
    /**
     * Create the DynamoDB mock
     */
    CreateMock(returnError) {
        const rejectResponse = new Error(`AWS Error`);
        // implement the AWS responses
        const awsResponses = {
            // delete response
            delete: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteItemOutput);
                }),
            },
            // get response
            get: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.GetItemOutput);
                }),
            },
            // put response
            put: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.PutItemOutput);
                }),
            },
            // scan response
            scan: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.ScanOutput);
                }),
            },
            // update response
            update: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.UpdateItemOutput);
                }),
            },
        };
        // create the functions
        let functions = new AWS.DynamoDB.DocumentClient();
        functions = {
            delete: () => awsResponses.delete,
            get: () => awsResponses.get,
            put: () => awsResponses.put,
            scan: () => awsResponses.scan,
            update: () => awsResponses.update,
        };
        return functions;
    }
}
exports.DynamoDBMock = DynamoDBMock;
//# sourceMappingURL=dynamodb-mock.js.map