"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_mock_1 = require("./base-mock");
// tslint:disable-next-line: no-var-requires
const AWS = require('aws-sdk');
/**
 * Lambda Mock class
 */
class LambdaMock extends base_mock_1.BaseMock {
    constructor() {
        super(...arguments);
        /**
         * Mocks an AWS.Lambda.EventSourceMappingConfiguration response
         */
        this.EventSourceMappingConfiguration = {};
        /**
         * Mocks an AWS.Lambda.InvocationResponse response
         */
        this.InvocationResponse = {};
        /**
         * Mocks an AWS.Lambda.InvokeAsyncResponse response
         */
        this.InvokeAsyncResponse = {};
        /**
         * Mocks an AWS.Lambda.ListEventSourceMappingsResponse response
         */
        this.ListEventSourceMappingsResponse = {};
    }
    /**
     * Create the Lambda mock
     */
    CreateMock(returnError) {
        const rejectResponse = new Error(`AWS Error`);
        // implement the AWS responses
        const awsResponses = {
            // invoke sync response
            invoke: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.InvocationResponse);
                }),
            },
            // invoke async response
            invokeAsync: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.InvokeAsyncResponse);
                }),
            },
            // get event source mapping response
            getEventSourceMapping: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.EventSourceMappingConfiguration);
                }),
            },
            // list event source mappings response
            listEventSourceMappings: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.ListEventSourceMappingsResponse);
                }),
            },
            // update event source mapping response
            updateEventSourceMapping: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.EventSourceMappingConfiguration);
                }),
            },
        };
        // create the functions
        let functions = new AWS.Lambda();
        functions = {
            invoke: () => awsResponses.invoke,
            invokeAsync: () => awsResponses.invokeAsync,
            getEventSourceMapping: () => awsResponses.getEventSourceMapping,
            listEventSourceMappings: () => awsResponses.listEventSourceMappings,
            updateEventSourceMapping: () => awsResponses.updateEventSourceMapping,
        };
        return functions;
    }
}
exports.LambdaMock = LambdaMock;
//# sourceMappingURL=lambda-mock.js.map