"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_mock_1 = require("./base-mock");
// tslint:disable-next-line: no-var-requires
const AWS = require('aws-sdk');
/**
 * SSM Mock class
 */
class SSMMock extends base_mock_1.BaseMock {
    constructor() {
        super(...arguments);
        /**
         * Mocks an AWS.SSM.CancelCommandResult response
         */
        this.CancelCommandResult = {};
        /**
         * Mocks an AWS.SSM.DeleteParameterResult response
         */
        this.DeleteParameterResult = {};
        /**
         * Mocks an AWS.SSM.GetParameterResult response
         */
        this.GetParameterResult = {};
        /**
         * Mocks an AWS.SSM.GetParametersByPathResult response
         */
        this.GetParametersByPathResult = {};
        /**
         * Mocks an AWS.SSM.PutParameterResult response
         */
        this.PutParameterResult = {};
        /**
         * Mocks an AWS.SSM.SendCommandResult response
         */
        this.SendCommandResult = {};
    }
    /**
     * Create the SSM mock
     */
    CreateMock(returnError) {
        const rejectResponse = new Error(`AWS Error`);
        // implement the AWS responses
        const awsResponses = {
            // cancel command response
            cancelCommand: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.CancelCommandResult);
                }),
            },
            // delete parameter response
            deleteParameter: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteParameterResult);
                }),
            },
            // get parameter response
            getParameter: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.GetParameterResult);
                }),
            },
            // get parameters by path response
            getParametersByPath: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.GetParametersByPathResult);
                }),
            },
            // put parameter response
            putParameter: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.PutParameterResult);
                }),
            },
            // send command response
            sendCommand: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.SendCommandResult);
                }),
            },
        };
        // create the functions
        let functions = new AWS.SSM();
        functions = {
            cancelCommand: () => awsResponses.cancelCommand,
            deleteParameter: () => awsResponses.deleteParameter,
            getParameter: () => awsResponses.getParameter,
            getParametersByPath: () => awsResponses.getParametersByPath,
            putParameter: () => awsResponses.putParameter,
            sendCommand: () => awsResponses.sendCommand,
        };
        return functions;
    }
}
exports.SSMMock = SSMMock;
//# sourceMappingURL=ssm-mock.js.map