"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../logger");
const test_values_1 = require("./test-values");
const helpers_1 = require("../helpers");
const mocks_1 = require("../mocks");
const logger = new logger_1.Logger(logger_1.LogLevel.Off);
const mockerResolves = new mocks_1.CloudWatchMock(false);
const cloudWatchHelperMockResolves = new helpers_1.CloudWatchHelper(logger, mockerResolves.Mock);
const mockerRejects = new mocks_1.CloudWatchMock(true);
const cloudWatchHelperMockRejects = new helpers_1.CloudWatchHelper(logger, mockerRejects.Mock);
const TestValues = new test_values_1.TestValuesClass();
/**
 * Test the PutMetricDataAsync method
 */
describe(`${helpers_1.CloudWatchHelper.name}.${cloudWatchHelperMockResolves.PutMetricDataAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.CloudWatchHelper.name}.${cloudWatchHelperMockResolves.PutMetricDataAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} namespace`, () => {
        const actual = cloudWatchHelperMockResolves.PutMetricDataAsync(TestValues.EmptyString, TestValues.MetricDatum);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} namespace`);
    });
    test(`${TestValues.ThrowsOnEmpty} metricData`, () => {
        const actual = cloudWatchHelperMockResolves.PutMetricDataAsync(TestValues.Namespace, TestValues.EmptyArray);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} metricData`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = cloudWatchHelperMockRejects.PutMetricDataAsync(TestValues.Namespace, TestValues.MetricDatum);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = cloudWatchHelperMockResolves.PutMetricDataAsync(TestValues.Namespace, TestValues.MetricDatum);
        return expect(actual).resolves.toEqual(mockerResolves.PutMetricDataResponse);
    });
});
//# sourceMappingURL=cloudwatch.spec.js.map