"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helpers_1 = require("../helpers");
const logger_1 = require("../logger");
const mocks_1 = require("../mocks");
const test_values_1 = require("./test-values");
const logger = new logger_1.Logger(logger_1.LogLevel.Off);
const mockerResolves = new mocks_1.DynamoDBMock(false);
const dynamoDBHelperMockResolves = new helpers_1.DynamoDBHelper(logger, mockerResolves.Mock);
const mockerRejects = new mocks_1.DynamoDBMock(true);
const dynamoDBHelperMockRejects = new helpers_1.DynamoDBHelper(logger, mockerRejects.Mock);
const TestValues = new test_values_1.TestValuesClass();
/**
 * Test the DeleteItemByKeyAsync method
 */
describe(`${helpers_1.DynamoDBHelper.name}.${dynamoDBHelperMockResolves.DeleteItemByKeyAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.DynamoDBHelper.name}.${dynamoDBHelperMockResolves.DeleteItemByKeyAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} tableName`, () => {
        const actual = dynamoDBHelperMockResolves.DeleteItemByKeyAsync(TestValues.EmptyString, TestValues.Key, TestValues.StringValue);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} tableName`);
    });
    test(`${TestValues.ThrowsOnEmpty} keyName`, () => {
        const actual = dynamoDBHelperMockResolves.DeleteItemByKeyAsync(TestValues.Name, TestValues.EmptyString, TestValues.StringValue);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} keyName`);
    });
    test(`${TestValues.ThrowsOnEmpty} keyValue`, () => {
        const actual = dynamoDBHelperMockResolves.DeleteItemByKeyAsync(TestValues.Name, TestValues.Key, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} keyValue`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = dynamoDBHelperMockRejects.DeleteItemByKeyAsync(TestValues.Name, TestValues.Key, TestValues.StringValue);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = dynamoDBHelperMockResolves.DeleteItemByKeyAsync(TestValues.Name, TestValues.Key, TestValues.StringValue);
        return expect(actual).resolves.toEqual(mockerResolves.DeleteItemOutput);
    });
});
/**
 * Test the GetItemByKeyAsync method
 */
describe(`${helpers_1.DynamoDBHelper.name}.${dynamoDBHelperMockResolves.GetItemByKeyAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.DynamoDBHelper.name}.${dynamoDBHelperMockResolves.GetItemByKeyAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} tableName`, () => {
        const actual = dynamoDBHelperMockResolves.GetItemByKeyAsync(TestValues.EmptyString, TestValues.Key, TestValues.StringValue);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} tableName`);
    });
    test(`${TestValues.ThrowsOnEmpty} keyName`, () => {
        const actual = dynamoDBHelperMockResolves.GetItemByKeyAsync(TestValues.Name, TestValues.EmptyString, TestValues.StringValue);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} keyName`);
    });
    test(`${TestValues.ThrowsOnEmpty} keyValue`, () => {
        const actual = dynamoDBHelperMockResolves.GetItemByKeyAsync(TestValues.Name, TestValues.Key, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} keyValue`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = dynamoDBHelperMockRejects.GetItemByKeyAsync(TestValues.Name, TestValues.Key, TestValues.StringValue);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = dynamoDBHelperMockResolves.GetItemByKeyAsync(TestValues.Name, TestValues.Key, TestValues.StringValue);
        return expect(actual).resolves.toEqual(mockerResolves.GetItemOutput);
    });
});
/**
 * Test the PutItemByKeyAsync method
 */
describe(`${helpers_1.DynamoDBHelper.name}.${dynamoDBHelperMockResolves.PutItemByKeyAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.DynamoDBHelper.name}.${dynamoDBHelperMockResolves.PutItemByKeyAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} tableName`, () => {
        const actual = dynamoDBHelperMockResolves.PutItemByKeyAsync(TestValues.EmptyString, TestValues.Item);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} tableName`);
    });
    test(`${TestValues.ThrowsOnEmpty} item`, () => {
        const actual = dynamoDBHelperMockResolves.PutItemByKeyAsync(TestValues.Name, TestValues.EmptyObject);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} item`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = dynamoDBHelperMockRejects.PutItemByKeyAsync(TestValues.Name, TestValues.Item);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = dynamoDBHelperMockResolves.PutItemByKeyAsync(TestValues.Name, TestValues.Item);
        return expect(actual).resolves.toEqual(mockerResolves.GetItemOutput);
    });
});
/**
 * Test the ScanAsync method
 */
describe(`${helpers_1.DynamoDBHelper.name}.${dynamoDBHelperMockResolves.ScanAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.DynamoDBHelper.name}.${dynamoDBHelperMockResolves.ScanAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} tableName`, () => {
        const actual = dynamoDBHelperMockResolves.ScanAsync(TestValues.EmptyString, TestValues.ExpressionAttributeNameMap, TestValues.ExpressionAttributeValueMap, TestValues.Expression);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} tableName`);
    });
    test(`${TestValues.ThrowsOnEmpty} attributeNames`, () => {
        const actual = dynamoDBHelperMockResolves.ScanAsync(TestValues.Name, TestValues.EmptyObject, TestValues.ExpressionAttributeValueMap, TestValues.Expression);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} attributeNames`);
    });
    test(`${TestValues.ThrowsOnEmpty} attributeValues`, () => {
        const actual = dynamoDBHelperMockResolves.ScanAsync(TestValues.Name, TestValues.ExpressionAttributeNameMap, TestValues.EmptyObject, TestValues.Expression);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} attributeValues`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = dynamoDBHelperMockRejects.ScanAsync(TestValues.Name, TestValues.ExpressionAttributeNameMap, TestValues.ExpressionAttributeValueMap, TestValues.Expression);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = dynamoDBHelperMockResolves.ScanAsync(TestValues.Name, TestValues.ExpressionAttributeNameMap, TestValues.ExpressionAttributeValueMap, TestValues.Expression);
        return expect(actual).resolves.toEqual(mockerResolves.ScanOutput);
    });
});
/**
 * Test the UpdateByKeyAsync method
 */
describe(`${helpers_1.DynamoDBHelper.name}.${dynamoDBHelperMockResolves.UpdateByKeyAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.DynamoDBHelper.name}.${dynamoDBHelperMockResolves.UpdateByKeyAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} tableName`, () => {
        const actual = dynamoDBHelperMockResolves.UpdateByKeyAsync(TestValues.EmptyString, TestValues.Key, TestValues.StringValue, TestValues.ExpressionAttributeNameMap, TestValues.ExpressionAttributeValueMap, TestValues.Expression, TestValues.Expression);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} tableName`);
    });
    test(`${TestValues.ThrowsOnEmpty} keyName`, () => {
        const actual = dynamoDBHelperMockResolves.UpdateByKeyAsync(TestValues.Name, TestValues.EmptyString, TestValues.StringValue, TestValues.ExpressionAttributeNameMap, TestValues.ExpressionAttributeValueMap, TestValues.Expression, TestValues.Expression);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} keyName`);
    });
    test(`${TestValues.ThrowsOnEmpty} keyValue`, () => {
        const actual = dynamoDBHelperMockResolves.UpdateByKeyAsync(TestValues.Name, TestValues.Key, TestValues.EmptyString, TestValues.ExpressionAttributeNameMap, TestValues.ExpressionAttributeValueMap, TestValues.Expression, TestValues.Expression);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} keyValue`);
    });
    test(`${TestValues.ThrowsOnEmpty} attributeNames`, () => {
        const actual = dynamoDBHelperMockResolves.UpdateByKeyAsync(TestValues.Name, TestValues.Key, TestValues.StringValue, TestValues.EmptyObject, TestValues.ExpressionAttributeValueMap, TestValues.Expression, TestValues.Expression);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} attributeNames`);
    });
    test(`${TestValues.ThrowsOnEmpty} attributeValues`, () => {
        const actual = dynamoDBHelperMockResolves.UpdateByKeyAsync(TestValues.Name, TestValues.Key, TestValues.StringValue, TestValues.ExpressionAttributeNameMap, TestValues.EmptyObject, TestValues.Expression, TestValues.Expression);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} attributeValues`);
    });
    test(`${TestValues.ThrowsOnEmpty} conditionExpression`, () => {
        const actual = dynamoDBHelperMockResolves.UpdateByKeyAsync(TestValues.Name, TestValues.Key, TestValues.StringValue, TestValues.ExpressionAttributeNameMap, TestValues.ExpressionAttributeValueMap, TestValues.EmptyString, TestValues.Expression);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} conditionExpression`);
    });
    test(`${TestValues.ThrowsOnEmpty} updateExpression`, () => {
        const actual = dynamoDBHelperMockResolves.UpdateByKeyAsync(TestValues.Name, TestValues.Key, TestValues.StringValue, TestValues.ExpressionAttributeNameMap, TestValues.ExpressionAttributeValueMap, TestValues.Expression, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} updateExpression`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = dynamoDBHelperMockRejects.UpdateByKeyAsync(TestValues.Name, TestValues.Key, TestValues.StringValue, TestValues.ExpressionAttributeNameMap, TestValues.ExpressionAttributeValueMap, TestValues.Expression, TestValues.Expression);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = dynamoDBHelperMockResolves.UpdateByKeyAsync(TestValues.Name, TestValues.Key, TestValues.StringValue, TestValues.ExpressionAttributeNameMap, TestValues.ExpressionAttributeValueMap, TestValues.Expression, TestValues.Expression);
        return expect(actual).resolves.toEqual(mockerResolves.ScanOutput);
    });
});
//# sourceMappingURL=dynamodb.spec.js.map