"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helpers_1 = require("../helpers");
const logger_1 = require("../logger");
const mocks_1 = require("../mocks");
const test_values_1 = require("./test-values");
const logger = new logger_1.Logger(logger_1.LogLevel.Off);
const mockerResolves = new mocks_1.KMSMock(false);
const kmsHelperMockResolves = new helpers_1.KMSHelper(logger, mockerResolves.Mock);
const mockerRejects = new mocks_1.KMSMock(true);
const kmsHelperMockRejects = new helpers_1.KMSHelper(logger, mockerRejects.Mock);
const TestValues = new test_values_1.TestValuesClass();
/**
 * Test the DecryptAsync method
 */
describe(`${helpers_1.KMSHelper.name}.${kmsHelperMockResolves.DecryptAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.KMSHelper.name}.${kmsHelperMockResolves.DecryptAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} encryptedValue`, () => {
        const actual = kmsHelperMockResolves.DecryptAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} encryptedValue`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = kmsHelperMockRejects.DecryptAsync(TestValues.StringValue);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = kmsHelperMockResolves.DecryptAsync(TestValues.StringValue);
        return expect(actual).resolves.toEqual(mockerResolves.DecryptResponse);
    });
});
/**
 * Test the EncryptAsync method
 */
describe(`${helpers_1.KMSHelper.name}.${kmsHelperMockResolves.EncryptAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.KMSHelper.name}.${kmsHelperMockResolves.EncryptAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} unencryptedValue`, () => {
        const actual = kmsHelperMockResolves.EncryptAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} unencryptedValue`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = kmsHelperMockRejects.EncryptAsync(TestValues.StringValue);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = kmsHelperMockResolves.EncryptAsync(TestValues.StringValue);
        return expect(actual).resolves.toEqual(mockerResolves.EncryptResponse);
    });
});
//# sourceMappingURL=kms.spec.js.map