"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helpers_1 = require("../helpers");
const logger_1 = require("../logger");
const mocks_1 = require("../mocks");
const test_values_1 = require("./test-values");
const logger = new logger_1.Logger(logger_1.LogLevel.Off);
const mockerResolves = new mocks_1.SESMock(false);
const sesHelperMockResolves = new helpers_1.SESHelper(logger, mockerResolves.Mock);
const mockerRejects = new mocks_1.SESMock(true);
const sesHelperMockRejects = new helpers_1.SESHelper(logger, mockerRejects.Mock);
const TestValues = new test_values_1.TestValuesClass();
/**
 * Test the SendEmailAsync method
 */
describe(`${helpers_1.SESHelper.name}.${sesHelperMockResolves.SendEmailAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.SESHelper.name}.${sesHelperMockResolves.SendEmailAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} subject`, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.EmptyString, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} subject`);
    });
    test(`${TestValues.ThrowsOnEmpty} toAddresses`, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.Subject, TestValues.EmptyArray, TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} toAddresses`);
    });
    test(`${TestValues.ThrowsOnEmpty} fromAddress`, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmptyString, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} fromAddress`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = sesHelperMockRejects.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = sesHelperMockResolves.SendEmailAsync(TestValues.Subject, [TestValues.EmailAddress], TestValues.EmailAddress, TestValues.Body);
        return expect(actual).resolves.toEqual(mockerResolves.SendEmailResponse);
    });
});
//# sourceMappingURL=ses.spec.js.map