"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helpers_1 = require("../helpers");
const logger_1 = require("../logger");
const mocks_1 = require("../mocks");
const test_values_1 = require("./test-values");
const logger = new logger_1.Logger(logger_1.LogLevel.Off);
const mockerResolves = new mocks_1.SSMMock(false);
const ssmHelperMockResolves = new helpers_1.SSMHelper(logger, mockerResolves.Mock);
const mockerRejects = new mocks_1.SSMMock(true);
const ssmHelperMockRejects = new helpers_1.SSMHelper(logger, mockerRejects.Mock);
const TestValues = new test_values_1.TestValuesClass();
/**
 * Test the CancelCommandAsync method
 */
describe(`${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.CancelCommandAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.CancelCommandAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} commandId`, () => {
        const actual = ssmHelperMockResolves.CancelCommandAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} commandId`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = ssmHelperMockRejects.CancelCommandAsync(TestValues.Id);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = ssmHelperMockResolves.CancelCommandAsync(TestValues.Id);
        return expect(actual).resolves.toEqual(mockerResolves.CancelCommandResult);
    });
});
/**
 * Test the DeleteParameterAsync method
 */
describe(`${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.DeleteParameterAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.DeleteParameterAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} name`, () => {
        const actual = ssmHelperMockResolves.DeleteParameterAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} name`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = ssmHelperMockRejects.DeleteParameterAsync(TestValues.Name);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = ssmHelperMockResolves.DeleteParameterAsync(TestValues.Name);
        return expect(actual).resolves.toEqual(mockerResolves.DeleteParameterResult);
    });
});
/**
 * Test the GetParameterAsync method
 */
describe(`${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.GetParameterAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.GetParameterAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} name`, () => {
        const actual = ssmHelperMockResolves.GetParameterAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} name`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = ssmHelperMockRejects.GetParameterAsync(TestValues.Name);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = ssmHelperMockResolves.GetParameterAsync(TestValues.Name);
        return expect(actual).resolves.toEqual(mockerResolves.GetParameterResult);
    });
});
/**
 * Test the GetParametersByPathAsync method
 */
describe(`${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.GetParametersByPathAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.GetParametersByPathAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} path`, () => {
        const actual = ssmHelperMockResolves.GetParametersByPathAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} path`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = ssmHelperMockRejects.GetParametersByPathAsync(TestValues.Path);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = ssmHelperMockResolves.GetParametersByPathAsync(TestValues.Path);
        return expect(actual).resolves.toEqual(mockerResolves.GetParametersByPathResult);
    });
});
/**
 * Test the PutParameterAsync method
 */
describe(`${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.PutParameterAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.PutParameterAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} name`, () => {
        const actual = ssmHelperMockResolves.PutParameterAsync(TestValues.EmptyString, TestValues.StringValue, TestValues.Type, TestValues.Description);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} name`);
    });
    test(`${TestValues.ThrowsOnEmpty} value`, () => {
        const actual = ssmHelperMockResolves.PutParameterAsync(TestValues.Name, TestValues.EmptyString, TestValues.Type, TestValues.Description);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} value`);
    });
    test(`${TestValues.ThrowsOnEmpty} type`, () => {
        const actual = ssmHelperMockResolves.PutParameterAsync(TestValues.Name, TestValues.StringValue, TestValues.EmptyString, TestValues.Description);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} type`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = ssmHelperMockRejects.PutParameterAsync(TestValues.Name, TestValues.StringValue, TestValues.Type, TestValues.Description);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = ssmHelperMockResolves.PutParameterAsync(TestValues.Name, TestValues.StringValue, TestValues.Type, TestValues.Description);
        return expect(actual).resolves.toEqual(mockerResolves.PutParameterResult);
    });
});
/**
 * Test the SendCommandAsync method
 */
describe(`${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.SendCommandAsync.name}`, () => {
    // set action for this method
    const action = `${helpers_1.SSMHelper.name}.${ssmHelperMockResolves.SendCommandAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} documentName`, () => {
        const actual = ssmHelperMockResolves.SendCommandAsync(TestValues.EmptyString, TestValues.Parameters, [TestValues.Id]);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} documentName`);
    });
    test(`${TestValues.ThrowsOnEmpty} parameters`, () => {
        const actual = ssmHelperMockResolves.SendCommandAsync(TestValues.Name, TestValues.EmptyObject, [TestValues.Id]);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} parameters`);
    });
    test(`${TestValues.ThrowsOnEmpty} instanceIds`, () => {
        const actual = ssmHelperMockResolves.SendCommandAsync(TestValues.Name, TestValues.Parameters, TestValues.EmptyArray);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} at least one instanceId`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = ssmHelperMockRejects.SendCommandAsync(TestValues.Name, TestValues.Parameters, [TestValues.Id]);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = ssmHelperMockResolves.SendCommandAsync(TestValues.Name, TestValues.Parameters, [TestValues.Id]);
        return expect(actual).resolves.toEqual(mockerResolves.SendCommandResult);
    });
});
//# sourceMappingURL=ssm.spec.js.map